/**********************************************************

	FILE				: can_demo.c
   
	AUTHOR			: Axiom Manufacturing    					     
						  
	PURPOSE			: HCS12 CAN demo functions
 
 *********************************************************/
 

#include <mc9s12hy64.h>				// derivative information
#include "can_demo.h"				// CAN header file

byte txbuff[8];						// transmit buffer
byte rxbuff[8];						// receive buffer

byte tx_data_len;						// tx buffer length	
byte rx_data_len;						// tx buffer length	

/**********************************************************
*	CAN_init
*
**********************************************************/
void Can_Init(void){
	
	CANCTL0 = 0x01;					//	enter init mode
	while(!(CANCTL1_INITAK));		// wait for init mode
	
	CANCTL1 = 0x80;					// enable CAN module, Ext OSC
	CANBTR0 = 0xC3;					// sync jump - 4 Tq clocks, prescalar = 3
	CANBTR1 = 0x3A;					// Tseg = 3, Tseg1 = 10, 1 sample per bit
	CANIDAC = 0x10;					// four 16-bit filters
	
	CANIDAR0 = ACC_CODE_ID100_HIGH;	// Filter 0, ID=0x100
	CANIDMR0 = MASK_CODE_ID_HIGH;
	CANIDAR1 = ACC_CODE_ID100_LOW;
	CANIDMR1 = MASK_CODE_ID_LOW;
	
	CANIDAR2 = 0x00;						// Filter 1, ID=0x000
	CANIDMR2 = MASK_CODE_ID_HIGH;
	CANIDAR3 = 0x00;
	CANIDMR3 = MASK_CODE_ID_LOW;
	
	CANIDAR4 = 0x00;						// Filter 2, ID=0x000
	CANIDMR4 = MASK_CODE_ID_HIGH;
	CANIDAR5 = 0x00;
	CANIDMR5 = MASK_CODE_ID_LOW;
	
	CANIDAR6 = 0x00;						// Filter 3, ID=0x000
	CANIDMR6 = MASK_CODE_ID_HIGH;
	CANIDAR7 = 0x00;
	CANIDMR7 = MASK_CODE_ID_LOW;
	
	CANCTL0 = 0x00;					// exit init mode
	while(CANCTL1_INITAK);			// wait until module exits init mode 
}


/**********************************************************
* CAN_Send_Frame
*
**********************************************************/
byte Can_Send_Frame(dword id, byte priority, byte length, byte *txdata){
	
	byte index;
	byte txbuffer = {0};
	
	if(!(CANTFLG))	
		return ERR_BUFFER_FULL;		// return error if Tx buffer full
	
	CANTBSEL = CANTFLG;				// get status of Tx buffer
	txbuffer = CANTBSEL;				// save status
	
	*((dword *) ((dword) (&CANTXIDR0))) = id;	// load id value to ID regs
	
//	*(&CANTXDSR0) = *txdata;		// load data to send  

	for(index=0; index<length; index++){
		*(&CANTXDSR0 + index) = txdata[index];	// load data to Tx Data Seg Regs
	}
	CANTXDLR = length;				// set data length
	CANTXTBPR = priority;			// set data buffer priority
	
	CANTFLG = txbuffer;				// start transmission
	
	while(!(CANTFLG & txbuffer));	// wait for Tx to complete
	*txbuff = CAN_NO_DATA;			// clear send buffer
	return (NO_ERR);
}

/**********************************************************
*	CAN_Get_Frame
*
*	read data from RxDSRx buffer
**********************************************************/
void CAN_Get_Frame(void){

	byte index, length;
	
	length = CANRXDLR;
	
	for(index=0; index<length; index++){
		rxbuff[index] = *(&CANRXDSR0 + index);
	}
	
}


/**********************************************************
* CAN_LED_Demo
*
**********************************************************/
void CAN_LED_Demo(byte cmd){
	
	switch(cmd){
		case 1:	PTR_PTR0 ^= 1;		// toggle LED1
					break;
		case 2:	PTR_PTR1 ^= 1;		// toggle LED2
					break;
		case 3:	PTR_PTR2 ^= 1;		// toggle LED3
					break;
		case 4:	PTR_PTR3 ^= 1;		// toggle LED4
					break;
	}
}

	
